# Enums

Enumeration types used throughout the library.

## EntityType

Used with the generic CRUD methods to specify which Grocy entity to operate on.

::: grocy.data_models.generic.EntityType

## TransactionType

Stock transaction types (purchase, consume, etc.).

::: grocy.grocy_api_client.TransactionType

## PeriodType

Chore scheduling period types.

::: grocy.data_models.chore.PeriodType

## AssignmentType

Chore assignment strategies.

::: grocy.data_models.chore.AssignmentType

## MealPlanItemType

Types of meal plan entries.

::: grocy.data_models.meal_items.MealPlanItemType
